@@ -3,7 +3,7 @@ import {MarkRole, ScopeRole} from './roles';
 
 export default function(spec) {
   const role = spec.role || '';
-  return (!role.indexOf('axis') || !role.indexOf('legend') || !role.indexOf('title'))
+  return (role.startsWith('axis') || role.startsWith('legend') || role.startsWith('title'))
     ? role
     : spec.type === GroupMark ? ScopeRole : (role || MarkRole);
 }
